Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(129)

Unified Diff: chrome/browser/extensions/api/web_request/web_request_api_helpers.h

Issue 10693073: Revert 145136 - Merge 144529 - Use the first_party_for_cookies URL to filter which requests the Web… (Closed) Base URL: svn://svn.chromium.org/chrome/branches/1180/src/
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/api/web_request/web_request_api_helpers.h
===================================================================
--- chrome/browser/extensions/api/web_request/web_request_api_helpers.h (revision 145167)
+++ chrome/browser/extensions/api/web_request/web_request_api_helpers.h (working copy)
@@ -28,11 +28,6 @@
class Value;
}
-namespace net {
-class BoundNetLog;
-class URLRequest;
-}
-
namespace extension_web_request_api_helpers {
typedef std::pair<std::string, std::string> ResponseHeader;
@@ -184,8 +179,8 @@
std::set<std::string>* conflicting_extensions,
EventLogEntries* event_log_entries);
-// Returns true if the request shall not be reported to extensions.
-bool HideRequest(net::URLRequest* request);
+// Returns true if requests for |url| shall not be reported to extensions.
+bool HideRequestForURL(const GURL& url);
// Returns whether |type| is a ResourceType that is handled by the web request
// API.

Powered by Google App Engine
This is Rietveld 408576698